# Python常用模块概览

Python是一种功能强大的编程语言，拥有丰富的标准库和第三方模块。本文章将为您简要介绍一些常用的Python模块，帮助您更高效地编写Python代码。

## os 模块

`os` 模块提供了许多与操作系统交互的功能，如文件操作、系统信息和进程管理等。

```python
import os
print(os.name)  # 输出操作系统名称
print(os.getcwd())  # 获取当前工作目录
os.mkdir('test_dir')  # 创建新目录
```

## sys 模块

`sys` 模块提供了与Python解释器和系统交互的功能，如访问命令行参数、退出程序等。

```python
import sys
print(sys.argv)  # 输出命令行参数列表
sys.exit(0)  # 退出程序
```

## datetime 模块

`datetime` 模块提供了处理日期和时间的类，方便进行日期计算和时间格式化。

```python
from datetime import datetime, timedelta
now = datetime.now()
print(now.strftime('%Y-%m-%d %H:%M:%S'))  # 格式化日期时间
future_date = now + timedelta(days=30)
print(future_date.strftime('%Y-%m-%d %H:%M:%S'))  # 计算未来日期并格式化
```

## json 模块

`json` 模块提供了对JSON数据的编码和解码功能，常用于数据交换和存储。

```python
import json
data = {'name': 'Alice', 'age': 30}
json_str = json.dumps(data)  # 将字典转换为JSON字符串
parsed_data = json.loads(json_str)  # 将JSON字符串解析为字典
```

## re 模块

`re` 模块提供了对正则表达式的支持，方便进行文本处理和模式匹配。

```python
import re
pattern = r'\d+'
text = 'There are 123 apples and 456 oranges.'
matches = re.findall(pattern, text)  # 查找所有匹配项
print(matches)  # 输出匹配结果
```

## requests 模块

`requests` 模块是一个HTTP库，提供了发送HTTP请求和解析响应的功能。

```python
import requests
response = requests.get('https://api.example.com/data')
data = response.json()  # 解析JSON响应数据
print(data)
```

## numpy 模块

`numpy` 是一个用于科学计算的模块，提供了多维数组对象、矩阵运算等功能。

```python
import numpy as np
arr = np.array([1, 2, 3, 4, 5])
print(arr + 2)  # 数组元素相加
matrix = np.array([[1, 2], [3, 4]])
print(matrix * 2)  # 矩阵元素相乘
```

这些仅仅是Python模块的一部分，您可以根据需要探索更多有用的模块。通过学习和使用这些模块，您将能够更高效地编写Python代码。